<?php
// api/src/Controller/CreateMediaObjectAction.php
namespace App\Controller;

use App\Entity\MediaObject;
use Doctrine\Persistence\ManagerRegistry;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpKernel\Exception\BadRequestHttpException;
use Symfony\Component\String\Slugger\SluggerInterface;
use Josantonius\MimeType\MimeType;
use Symfony\Component\HttpFoundation\File\Exception\FileException;
use Symfony\Component\HttpKernel\Attribute\AsController;

#[AsController]
final class CreateMediaObjectAction extends AbstractController
{
    public function __invoke(Request $request, SluggerInterface $slugger, ManagerRegistry $doctrine): MediaObject
    {
        //$uploadedFile = $request->files->get('file');
        $uploadedFile = $request->files->get('file');

        if (!$uploadedFile) {
            throw new BadRequestHttpException('"file" is required');
        }

        $ext = pathinfo($uploadedFile->getClientOriginalName(), PATHINFO_EXTENSION);
        $originalFilename = pathinfo($uploadedFile->getClientOriginalName(), PATHINFO_FILENAME);
        // this is needed to safely include the file name as part of the URL
        $safeFilename = $slugger->slug($originalFilename);
        $newFilename = uniqid() . '-' . $safeFilename . '.' . $uploadedFile->guessExtension();

        $mimeType = new MimeType();
        $mime  = $mimeType->getMime($ext);

        // Move the file to the directory where brochures are stored
        try {
            $uploadedFile->move(
                $this->getParameter('media_directory'),
                $newFilename
            );
        } catch (FileException $e) {
            // ... handle exception if something happens during file upload
        }

        $entityManager = $doctrine->getManager();
        $mediaObject = new MediaObject();
        $mediaObject->setOriginalFileName($originalFilename. '.' . $ext);
        $mediaObject->setFileName($newFilename);
        $mediaObject->setFileExtension($ext);
        $mediaObject->setMimeType($mime);
        /*$mediaObject->setContentUrl(
            new File($this->getParameter('media_directory') . '/' . $newFilename)
        );*/
        $entityManager->persist($mediaObject);
        $entityManager->flush();
        return $mediaObject;
    }

}
