<?php

namespace App\Entity;

use ApiPlatform\Metadata\ApiProperty;
use ApiPlatform\Metadata\ApiResource;
use ApiPlatform\Metadata\Get;
use ApiPlatform\Metadata\GetCollection;
use ApiPlatform\Metadata\Post;
use ApiPlatform\Metadata\Put;
use App\Controller\Agence\CreateAgenceRequestAction;
use App\Controller\Agence\DeleteAgenceRequestAction;
use App\Controller\Agence\GetAgenceRequestAction;
use App\Controller\Agence\ListAgenceRequestAction;
use App\Controller\Agence\UpdateAgenceRequestAction;
use App\Payload\AgencePaylod;
use App\Repository\AgenceRepository;
use Doctrine\ORM\Mapping as ORM;

#[ORM\Entity(repositoryClass: AgenceRepository::class)]
#[ApiResource(
    routePrefix: '',
    operations: [
        new Get(uriTemplate: '/white-api/agence/by-id/{id}',
        controller: GetAgenceRequestAction::class),
        new GetCollection(uriTemplate: '/white-api/agence/list',
        controller: ListAgenceRequestAction::class),
        new Post(uriTemplate: '/auth/agence/create',
        controller: CreateAgenceRequestAction::class,
        input: AgencePaylod::class),
        new Put(uriTemplate: '/auth/agence/modify/{id}',
        controller: UpdateAgenceRequestAction::class,
        input: AgencePaylod::class),
        new Get(uriTemplate: '/auth/agence/delete/{id}',
        controller: DeleteAgenceRequestAction::class),
     ],
     formats: [
        'json' =>    ['application/json'],
        'xml' =>     ['application/xml', 'text/xml'],
     ],
     paginationEnabled: false,
     order: ['createdAt' => 'DESC', 'libelle' => 'ASC'],
)]
class Agence extends Commun 
{
    #[ORM\Id]
    #[ORM\GeneratedValue]
    #[ORM\Column]
    private ?int $id = null;

    #[ORM\Column(length: 255)]
    private ?string $libelle = null;

    #[ORM\ManyToOne(targetEntity: Agence::class)]
    #[ApiProperty(writable: false, writableLink: true, readableLink: true)]
    private ?Antenne $antenne = null;

    public function getId(): ?int
    {
        return $this->id;
    }

    public function getLibelle(): ?string
    {
        return $this->libelle;
    }

    public function setLibelle(string $libelle): static
    {
        $this->libelle = $libelle;

        return $this;
    }

    public function getAntenne(): ?Antenne
    {
        return $this->antenne;
    }

    public function setAntenne(?Antenne $antenne): static
    {
        $this->antenne = $antenne;

        return $this;
    }

}
