<?php

namespace App\Entity;

use ApiPlatform\Metadata\ApiResource;
use ApiPlatform\Metadata\Get;
use ApiPlatform\Metadata\GetCollection;
use ApiPlatform\Metadata\Post;
use ApiPlatform\Metadata\Put;
use App\Controller\Antenne\CreateAntenneRequestAction;
use App\Controller\Antenne\DeleteAntenneRequestAction;
use App\Controller\Antenne\GetAntenneRequestAction;
use App\Controller\Antenne\ListAntenneRequestAction;
use App\Controller\Antenne\UpdateAntenneRequestAction;
use App\Repository\AntenneRepository;
use Doctrine\ORM\Mapping as ORM;

#[ORM\Entity(repositoryClass: AntenneRepository::class)]
#[ApiResource(
    routePrefix: '',
    operations: [
        new Get(uriTemplate: '/white-api/antenne/by-id/{id}',
        controller: GetAntenneRequestAction::class),
        new GetCollection(uriTemplate: '/white-api/antenne/list',
        controller: ListAntenneRequestAction::class),
        new Post(uriTemplate: '/auth/antenne/create',
        controller: CreateAntenneRequestAction::class,
        input: Antenne::class),
        new Put(uriTemplate: '/auth/antenne/modify/{id}',
        controller: UpdateAntenneRequestAction::class,
        input: Antenne::class),
        new Get(uriTemplate: '/auth/antenne/delete/{id}',
        controller: DeleteAntenneRequestAction::class),
     ],
     formats: [
        'json' =>    ['application/json'],
        'xml' =>     ['application/xml', 'text/xml'],
     ],
     paginationEnabled: false,
     order: ['createdAt' => 'DESC', 'libelle' => 'ASC'],
)]
class Antenne extends Commun 
{
    #[ORM\Id]
    #[ORM\GeneratedValue]
    #[ORM\Column]
    private ?int $id = null;

    #[ORM\Column(length: 255)]
    private ?string $libelle = null;

    public function getId(): ?int
    {
        return $this->id;
    }

    public function getLibelle(): ?string
    {
        return $this->libelle;
    }

    public function setLibelle(string $libelle): static
    {
        $this->libelle = $libelle;

        return $this;
    }

}
