<?php

namespace App\Entity;

use ApiPlatform\Metadata\ApiResource;
use ApiPlatform\Metadata\Get;
use ApiPlatform\Metadata\GetCollection;
use ApiPlatform\Metadata\Post;
use ApiPlatform\Metadata\Put;
use App\Controller\CategorieDocument\CreateCategorieDocumentRequestAction;
use App\Controller\CategorieDocument\DeleteCategorieDocumentRequestAction;
use App\Controller\CategorieDocument\GetCategorieDocumentRequestAction;
use App\Controller\CategorieDocument\ListCategorieDocumentRequestAction;
use App\Controller\CategorieDocument\UpdateCategorieDocumentRequestAction;
use App\Repository\CategorieDocumentRepository;
use Doctrine\ORM\Mapping as ORM;

#[ApiResource(
     routePrefix: '',
     operations: [
        new Get(uriTemplate: '/white-api/categorie-document/by-id/{id}',
        controller: GetCategorieDocumentRequestAction::class),
        new GetCollection(uriTemplate: '/white-api/categorie-document/list',
        controller: ListCategorieDocumentRequestAction::class),
        new Post(uriTemplate: '/auth/categorie-document/create',
        controller: CreateCategorieDocumentRequestAction::class,
        input: CategorieDocument::class),
        new Put(uriTemplate: '/auth/categorie-document/modify/{id}',
        controller: UpdateCategorieDocumentRequestAction::class,
        input: CategorieDocument::class),
        new Get(uriTemplate: '/auth/categorie-document/delete/{id}',
        controller: DeleteCategorieDocumentRequestAction::class),
     ],
     formats: [
        'json' =>    ['application/json'],
        'xml' =>     ['application/xml', 'text/xml'],
     ],
     paginationEnabled: false,
     order: ['createdAt' => 'DESC', 'libelle' => 'ASC'],
)]
#[ORM\Entity(repositoryClass: CategorieDocumentRepository::class)]
#[ORM\Table(name: '`categorie_document`')]
class CategorieDocument extends Commun 
{
    #[ORM\Id]
    #[ORM\GeneratedValue]
    #[ORM\Column]
    private ?int $id = null;

    #[ORM\Column(length: 128)]
    private ?string $libelle = null;

    public function getId(): ?int
    {
        return $this->id;
    }

    public function getLibelle(): ?string
    {
        return $this->libelle;
    }

    public function setLibelle(string $libelle): static
    {
        $this->libelle = $libelle;

        return $this;
    }

}
