<?php

namespace App\Entity;


use ApiPlatform\Metadata\ApiFilter;
use ApiPlatform\Metadata\ApiProperty;
use ApiPlatform\Metadata\ApiResource;
use ApiPlatform\Metadata\Get;
use ApiPlatform\Metadata\GetCollection;
use ApiPlatform\Metadata\Post;
use ApiPlatform\Metadata\Put;
use App\Controller\CategoriePublication\CreateCategoriePublicationRequestAction;
use App\Controller\CategoriePublication\DeleteCategoriePublicationRequestAction;
use App\Controller\CategoriePublication\GetCategoriePublicationRequestAction;
use App\Controller\CategoriePublication\ListCategoriePublicationRequestAction;
use App\Controller\CategoriePublication\UpdateCategoriePublicationRequestAction;
use App\Repository\CategoriePublicationRepository;
use Doctrine\ORM\Mapping as ORM;
//use Symfony\Bridge\Doctrine\IdGenerator\UuidV4Generator;
//use Symfony\Component\Uid\Uuid;
use Symfony\Component\String\Slugger\SluggerInterface;

#[ORM\Entity(repositoryClass: CategoriePublicationRepository::class)]
#[ORM\Table(name: '`categorie_publication`')]
#[ApiResource(
    routePrefix: '',
    operations: [
        new Get(uriTemplate: '/white-api/categorie-publication/by-id/{id}',
        controller: GetCategoriePublicationRequestAction::class),
        new GetCollection(uriTemplate: '/white-api/categorie-publication/list',
        controller: ListCategoriePublicationRequestAction::class),
        new Post(uriTemplate: '/white-api/categorie-publication/create',
        controller: CreateCategoriePublicationRequestAction::class,
        input: CategoriePublication::class),
        new Put(uriTemplate: '/auth/categorie-publication/modify/{id}',
        controller: UpdateCategoriePublicationRequestAction::class,
        input: CategoriePublication::class),
        new Get(uriTemplate: '/auth/categorie-publication/delete/{id}',
        controller: DeleteCategoriePublicationRequestAction::class),
    ],
    formats: [
        'json' =>    ['application/json'],
        'xml' =>     ['application/xml', 'text/xml'],
    ],
    paginationEnabled: false,
    order: ['createdAt' => 'DESC', 'libelle' => 'ASC'],
)]
class CategoriePublication extends Commun 
{
    #[ORM\Id]
    #[ORM\GeneratedValue]
    #[ORM\Column]
    private ?int $id = null;

    #[ORM\Column(length: 128)]
    private ?string $libelle = null;

    #[ORM\Column(length: 255)]
    #[ApiProperty(writable: false, writableLink: true, readableLink: true)]
    private ?string $slug = null;

    public function computeSlug(SluggerInterface $slugger)
    {
        if (!$this->slug || '-' === $this->slug) {
            $this->slug = (string) $slugger->slug((string) $this->getLibelle())->lower();
        }
    }

    public function getId(): ?int
    {
        return $this->id;
    }

    public function getLibelle(): ?string
    {
        return $this->libelle;
    }

    public function setLibelle(string $libelle): static
    {
        $this->libelle = $libelle;

        return $this;
    }

    public function getSlug(): ?string
    {
        return $this->slug;
    }

    public function setSlug(string $slug): static
    {
        $this->slug = $slug;

        return $this;
    }
}
