<?php

namespace App\Entity;

use ApiPlatform\Metadata\ApiResource;
use ApiPlatform\Metadata\Get;
use ApiPlatform\Metadata\GetCollection;
use ApiPlatform\Metadata\Post;
use ApiPlatform\Metadata\Put;
use App\Controller\Contact\CreateContactRequestAction;
use App\Controller\Contact\DeleteContactRequestAction;
use App\Controller\Contact\GetContactRequestAction;
use App\Controller\Contact\ListContactRequestAction;
use App\Repository\ContactRepository;
use Doctrine\ORM\Mapping as ORM;

#[ORM\Entity(repositoryClass: ContactRepository::class)]
#[ApiResource(
    routePrefix: '',
    operations: [
        new Get(uriTemplate: '/white-api/contact/by-id/{id}',
        controller: GetContactRequestAction::class),
        new GetCollection(uriTemplate: '/auth/contact/list',
        controller: ListContactRequestAction::class),
        new Post(uriTemplate: '/white-api/contact/create',
        controller: CreateContactRequestAction::class,
        input: Contact::class),
        /*new Put(uriTemplate: '/auth/contact/modify/{id}',
        controller: UpdateContactRequestAction::class,
        input: Contact::class),*/
        new Get(uriTemplate: '/auth/contact/delete/{id}',
        controller: DeleteContactRequestAction::class),
     ],
     formats: [
        'json' =>    ['application/json'],
        'xml' =>     ['application/xml', 'text/xml'],
     ],
     paginationEnabled: false,
     order: ['createdAt' => 'DESC', 'libelle' => 'ASC'],
)]
class Contact extends Commun 
{
    #[ORM\Id]
    #[ORM\GeneratedValue]
    #[ORM\Column]
    private ?int $id = null;

    #[ORM\Column(length: 255)]
    private ?string $name = null;

    #[ORM\Column(length: 255)]
    private ?string $tel = null;

    #[ORM\Column(length: 255)]
    private ?string $email = null;

    #[ORM\Column(length: 255)]
    private ?string $subject = null;

    #[ORM\Column(length: 255)]
    private ?string $contentMessage = null;

    public function getId(): ?int
    {
        return $this->id;
    }

    public function getName(): ?string
    {
        return $this->name;
    }

    public function setName(string $name): static
    {
        $this->name = $name;

        return $this;
    }

    public function getTel(): ?string
    {
        return $this->tel;
    }

    public function setTel(string $tel): static
    {
        $this->tel = $tel;

        return $this;
    }

    public function getEmail(): ?string
    {
        return $this->email;
    }

    public function setEmail(string $email): static
    {
        $this->email = $email;

        return $this;
    }

    public function getSubject(): ?string
    {
        return $this->subject;
    }

    public function setSubject(string $subject): static
    {
        $this->subject = $subject;

        return $this;
    }

    public function getContentMessage(): ?string
    {
        return $this->contentMessage;
    }

    public function setContentMessage(string $contentMessage): static
    {
        $this->contentMessage = $contentMessage;

        return $this;
    }
}
