<?php

namespace App\Entity;

use ApiPlatform\Metadata\ApiResource;
use ApiPlatform\Metadata\Get;
use ApiPlatform\Metadata\GetCollection;
use ApiPlatform\Metadata\Post;
use ApiPlatform\Metadata\Put;
use App\Controller\CustomerSubject\CreateCustomerSubjectRequestAction;
use App\Controller\CustomerSubject\DeleteCustomerSubjectRequestAction;
use App\Controller\CustomerSubject\GetCustomerSubjectRequestAction;
use App\Controller\CustomerSubject\ListCustomerSubjectRequestAction;
use App\Repository\CustomerSubjectRepository;
use Doctrine\ORM\Mapping as ORM;

#[ORM\Entity(repositoryClass: CustomerSubjectRepository::class)]
#[ApiResource(
    routePrefix: '',
    operations: [
        new Get(uriTemplate: '/white-api/customer-subject/by-id/{id}',
        controller: GetCustomerSubjectRequestAction::class),
        new GetCollection(uriTemplate: '/auth/customer-subject/list',
        controller: ListCustomerSubjectRequestAction::class),
        new Post(uriTemplate: '/white-api/customer-subject/create',
        controller: CreateCustomerSubjectRequestAction::class,
        input: CustomerSubject::class),
        /*new Put(uriTemplate: '/auth/customer-subject/modify/{id}',
        controller: UpdateCustomerSubjectRequestAction::class,
        input: CustomerSubject::class),*/
        new Get(uriTemplate: '/auth/customer-subject/delete/{id}',
        controller: DeleteCustomerSubjectRequestAction::class),
     ],
     formats: [
        'json' =>    ['application/json'],
        'xml' =>     ['application/xml', 'text/xml'],
     ],
     paginationEnabled: false,
     order: ['createdAt' => 'DESC', 'libelle' => 'ASC'],
)]
class CustomerSubject extends Commun 
{
    #[ORM\Id]
    #[ORM\GeneratedValue]
    #[ORM\Column]
    private ?int $id = null;

    #[ORM\Column(length: 255)]
    private ?string $categorieSubject = null;

    #[ORM\Column(length: 255)]
    private ?string $description = null;

    #[ORM\OneToOne(cascade: ['persist', 'remove'])]
    private ?MediaObject $mediaObject = null;

    public function getId(): ?int
    {
        return $this->id;
    }

    public function getCategorieSubject(): ?string
    {
        return $this->categorieSubject;
    }

    public function setCategorieSubject(string $categorieSubject): static
    {
        $this->categorieSubject = $categorieSubject;

        return $this;
    }

    public function getDescription(): ?string
    {
        return $this->description;
    }

    public function setDescription(string $description): static
    {
        $this->description = $description;

        return $this;
    }

    public function getMediaObject(): ?MediaObject
    {
        return $this->mediaObject;
    }

    public function setMediaObject(?MediaObject $mediaObject): static
    {
        $this->mediaObject = $mediaObject;

        return $this;
    }
}
