<?php

namespace App\Entity;

use ApiPlatform\Metadata\ApiProperty;
use ApiPlatform\Metadata\ApiResource;
use ApiPlatform\Metadata\Get;
use ApiPlatform\Metadata\GetCollection;
use ApiPlatform\Metadata\Post;
use ApiPlatform\Metadata\Put;
use App\Controller\Docutheque\CreateDocuthequeRequestAction;
use App\Controller\Docutheque\DeleteDocuthequeRequestAction;
use App\Controller\Docutheque\GetDocuthequeRequestAction;
use App\Controller\Docutheque\ListDocuthequeRequestAction;
use App\Controller\Docutheque\UpdateDocuthequeRequestAction;
use App\Payload\DocuthequePaylod;
use App\Repository\DocuthequeRepository;
use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;
use Doctrine\ORM\Mapping as ORM;

#[ORM\Entity(repositoryClass: DocuthequeRepository::class)]
#[ApiResource(
    routePrefix: '',
    operations: [
        new Get(uriTemplate: '/white-api/docutheque/by-id/{id}',
        controller: GetDocuthequeRequestAction::class),
        new GetCollection(uriTemplate: '/white-api/docutheque/list',
        controller: ListDocuthequeRequestAction::class),
        new Post(uriTemplate: '/auth/docutheque/create',
        controller: CreateDocuthequeRequestAction::class,
        input: DocuthequePaylod::class),
        new Put(uriTemplate: '/auth/docutheque/modify/{id}',
        controller: UpdateDocuthequeRequestAction::class,
        input: DocuthequePaylod::class),
        new Get(uriTemplate: '/auth/docutheque/delete/{id}',
        controller: DeleteDocuthequeRequestAction::class),
     ],
     formats: [
        'json' =>    ['application/json'],
        'xml' =>     ['application/xml', 'text/xml'],
     ],
     paginationEnabled: false,
     order: ['createdAt' => 'DESC', 'libelle' => 'ASC'],
)]
class Docutheque extends Commun 
{
    #[ORM\Id]
    #[ORM\GeneratedValue]
    #[ORM\Column]
    private ?int $id = null;

    #[ORM\Column(length: 255)]
    private ?string $titre = null;

    #[ORM\Column(length: 255, nullable: true)]
    private ?string $contenu = null;

    #[ORM\Column(nullable: true)]
    private ?\DateTimeImmutable $publishedAt = null;

    #[ORM\Column]
    private ?bool $estPubliser = null;

    #[ORM\Column]
    private ?bool $estArchiver = null;

    #[ORM\Column(length: 255)]
    private ?string $auteur = null;

    #[ORM\ManyToOne(targetEntity: CategorieDocument::class)]
    #[ORM\JoinColumn(nullable: false)]
    #[ApiProperty(writable: false, writableLink: true, readableLink: true)]
    private ?CategorieDocument $categorieDocument = null;

    #[ORM\ManyToOne(targetEntity: MediaObject::class)]
    #[ORM\JoinColumn(nullable: true)]
    #[ApiProperty(writable: false, writableLink: true, readableLink: true)]
    private ?MediaObject $mediaObject = null;

    #[ORM\ManyToMany(targetEntity: Tag::class, inversedBy: 'docutheques', cascade: ['persist'])]
    #[ApiProperty(writable: false, writableLink: true, readableLink: true)]
    private Collection $tags;

    public function __construct()
    {
        $this->tags = new ArrayCollection();
    }

    public function getId(): ?int
    {
        return $this->id;
    }

    public function getTitre(): ?string
    {
        return $this->titre;
    }

    public function setTitre(string $titre): static
    {
        $this->titre = $titre;

        return $this;
    }

    public function getContenu(): ?string
    {
        return $this->contenu;
    }

    public function setContenu(?string $contenu): static
    {
        $this->contenu = $contenu;

        return $this;
    }

    public function getPublishedAt(): ?\DateTimeImmutable
    {
        return $this->publishedAt;
    }

    public function setPublishedAt(?\DateTimeImmutable $publishedAt): static
    {
        $this->publishedAt = $publishedAt;

        return $this;
    }

    public function isEstPubliser(): ?bool
    {
        return $this->estPubliser;
    }

    public function setEstPubliser(bool $estPubliser): static
    {
        $this->estPubliser = $estPubliser;

        return $this;
    }

    public function isEstArchiver(): ?bool
    {
        return $this->estArchiver;
    }

    public function setEstArchiver(bool $estArchiver): static
    {
        $this->estArchiver = $estArchiver;

        return $this;
    }

    public function getAuteur(): ?string
    {
        return $this->auteur;
    }

    public function setAuteur(string $auteur): static
    {
        $this->auteur = $auteur;

        return $this;
    }

    public function getCategorieDocument(): ?CategorieDocument
    {
        return $this->categorieDocument;
    }

    public function setCategorieDocument(?CategorieDocument $categorieDocument): static
    {
        $this->categorieDocument = $categorieDocument;

        return $this;
    }

    public function getMediaObject(): ?MediaObject
    {
        return $this->mediaObject;
    }

    public function setMediaObject(?MediaObject $mediaObject): static
    {
        $this->mediaObject = $mediaObject;

        return $this;
    }

    /**
     * @return Collection<int, Tag>
     */
    public function getTags(): Collection
    {
        return $this->tags;
    }

    public function addTag(Tag $tag): static
    {
        if (!$this->tags->contains($tag)) {
            $this->tags->add($tag);
            $tag->addDocutheque($this);
        }

        return $this;
    }

    public function removeTag(Tag $tag): static
    {
        if ($this->tags->removeElement($tag)) {
            $tag->removeDocutheque($this);
        }

        return $this;
    }
}
