<?php

namespace App\Entity;

use ApiPlatform\Metadata\ApiResource;
use ApiPlatform\Metadata\Get;
use ApiPlatform\Metadata\GetCollection;
use ApiPlatform\Metadata\Post;
use ApiPlatform\Metadata\Put;
use App\Controller\NewLetter\CreateNewLetterRequestAction;
use App\Controller\NewLetter\DeleteNewLetterRequestAction;
use App\Controller\NewLetter\GetNewLetterRequestAction;
use App\Controller\NewLetter\ListNewLetterRequestAction;
use App\Controller\NewLetter\UpdateNewLetterRequestAction;
use App\Repository\NewLetterRepository;
use Doctrine\ORM\Mapping as ORM;

#[ORM\Entity(repositoryClass: NewLetterRepository::class)]
#[ApiResource(
    routePrefix: '/auth/new-letter',
    operations: [
        new Get(uriTemplate: '/white-api/new-letter/by-id/{id}',
        controller: GetNewLetterRequestAction::class),
        new GetCollection(uriTemplate: '/white-api/new-letter/list',
        controller: ListNewLetterRequestAction::class),
        new Post(uriTemplate: '/auth/new-letter/create',
        controller: CreateNewLetterRequestAction::class,
        input: NewLetter::class),
        new Put(uriTemplate: '/auth/new-letter/modify/{id}',
        controller: UpdateNewLetterRequestAction::class,
        input: NewLetter::class),
        new Get(uriTemplate: '/auth/new-letter/delete/{id}',
        controller: DeleteNewLetterRequestAction::class),
     ],
     formats: [
        'json' =>    ['application/json'],
        'xml' =>     ['application/xml', 'text/xml'],
     ],
     paginationEnabled: false,
     order: ['createdAt' => 'DESC', 'libelle' => 'ASC'],
)]
class NewLetter  extends Commun 
{
    #[ORM\Id]
    #[ORM\GeneratedValue]
    #[ORM\Column]
    private ?int $id = null;

    #[ORM\Column(length: 255)]
    private ?string $email = null;

    #[ORM\Column]
    private ?bool $estVerifier = null;

    #[ORM\Column(length: 20)]
    private ?string $codeForUpdating = null;

    public function __construct()
    {
        $this->estVerifier = false;
        //$this->$codeForUpdating = sha1(mt_rand(1, 90000) . 'SALT');
    }

    public function getId(): ?int
    {
        return $this->id;
    }

    public function getEmail(): ?string
    {
        return $this->email;
    }

    public function setEmail(string $email): static
    {
        $this->email = $email;

        return $this;
    }

    public function isEstVerifier(): ?bool
    {
        return $this->estVerifier;
    }

    public function setEstVerifier(bool $estVerifier): static
    {
        $this->estVerifier = $estVerifier;

        return $this;
    }

    public function getCodeForUpdating(): ?string
    {
        return $this->codeForUpdating;
    }

    public function setCodeForUpdating(string $codeForUpdating): static
    {
        $this->codeForUpdating = $codeForUpdating;

        return $this;
    }
}
