<?php

namespace App\Entity;

use ApiPlatform\Metadata\ApiProperty;
use ApiPlatform\Metadata\ApiResource;
use ApiPlatform\Metadata\Get;
use ApiPlatform\Metadata\GetCollection;
use ApiPlatform\Metadata\Post;
use ApiPlatform\Metadata\Put;
use App\Controller\Tag\CreateTagRequestAction;
use App\Controller\Tag\DeleteTagRequestAction;
use App\Controller\Tag\GetTagRequestAction;
use App\Controller\Tag\ListTagRequestAction;
use App\Controller\Tag\UpdateTagRequestAction;
use App\Repository\TagRepository;
use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;
use Doctrine\ORM\Mapping as ORM;

#[ORM\Entity(repositoryClass: TagRepository::class)]
#[ApiResource(
    routePrefix: '',
    operations: [
        new Get(uriTemplate: '/white-api/tag/by-id/{id}',
        controller: GetTagRequestAction::class),
        new GetCollection(uriTemplate: '/white-api/tag/list',
        controller: ListTagRequestAction::class),
        new Post(uriTemplate: '/auth/tag/create',
        controller: CreateTagRequestAction::class,
        input: Tag::class),
        new Put(uriTemplate: '/auth/tag/modify/{id}',
        controller: UpdateTagRequestAction::class,
        input: Tag::class),
        new Get(uriTemplate: '/auth/tag/delete/{id}',
        controller: DeleteTagRequestAction::class),
     ],
     formats: [
        'json' =>    ['application/json'],
        'xml' =>     ['application/xml', 'text/xml'],
     ],
     paginationEnabled: false,
     order: ['createdAt' => 'DESC', 'libelle' => 'ASC'],
)]
class Tag  extends Commun 
{
    #[ORM\Id]
    #[ORM\GeneratedValue]
    #[ORM\Column]
    private ?int $id = null;

    #[ORM\Column(length: 255)]
    private ?string $libelle = null;

    #[ORM\ManyToMany(targetEntity: Publication::class, mappedBy: 'tags')]
    #[ApiProperty(writable: false, writableLink: false, readableLink: false)]
    private Collection $publications;

    #[ORM\ManyToMany(targetEntity: Docutheque::class, mappedBy: 'tags')]
    #[ApiProperty(writable: false, writableLink: false, readableLink: false)]
    private Collection $docutheques;

    public function __construct()
    {
        $this->publications = new ArrayCollection();
        $this->docutheques = new ArrayCollection();
    }

    public function getId(): ?int
    {
        return $this->id;
    }

    public function getLibelle(): ?string
    {
        return $this->libelle;
    }

    public function setLibelle(string $libelle): static
    {
        $this->libelle = $libelle;

        return $this;
    }

    /**
     * @return Collection<int, Publication>
     */
    public function getPublications(): Collection
    {
        return $this->publications;
    }

    public function addPublication(Publication $publication): static
    {
        if (!$this->publications->contains($publication)) {
            $this->publications->add($publication);
        }

        return $this;
    }

    public function removePublication(Publication $publication): static
    {
        $this->publications->removeElement($publication);

        return $this;
    }

    /**
     * @return Collection<int, Docutheque>
     */
    public function getDocutheques(): Collection
    {
        return $this->docutheques;
    }

    public function addDocutheque(Docutheque $docutheque): static
    {
        if (!$this->docutheques->contains($docutheque)) {
            $this->docutheques->add($docutheque);
        }

        return $this;
    }

    public function removeDocutheque(Docutheque $docutheque): static
    {
        $this->docutheques->removeElement($docutheque);

        return $this;
    }

}
